==> conventional_commits_next_version_lib-0.1.0.crate: conventional_commits_next_version_lib-0.1.0/README.md <==
# Conventional Commits Next Version Library
[![Documentation](https://docs.rs/conventional_commits_next_version_lib/badge.svg)](https://docs.rs/conventional_commits_next_version_lib)
[![crates.io](https://img.shields.io/crates/v/conventional_commits_next_version_lib)](https://crates.io/crates/conventional_commits_next_version_lib)
[![Pipeline Status](https://gitlab.com/DeveloperC/conventional_commits_next_version/badges/master/pipeline.svg)](https://gitlab.com/DeveloperC/conventional_commits_next_version/commits/master)
[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg)](https://conventionalcommits.org)
[![License](https://img.shields.io/badge/License-AGPLv3-blue.svg)](https://www.gnu.org/licenses/agpl-3.0)


A tooling and language agnostic utility to calculate the next semantic version based on the Conventional Commits since the prior version. Supports monorepos.


## Content
 * [Usage](#usage)
   + [Usage - Logging](#usage-logging)
 * [Issues/Feature Requests](#issuesfeature-requests)


## Usage


### Usage - Logging
The crate `log` is used to provide logging.
The environment variable `RUST_LOG` can be used to set the logging level.
See [https://crates.io/crates/log](https://crates.io/crates/log) for more detailed documentation.


## Issues/Feature Requests
To report an issue or request a new feature use [https://gitlab.com/DeveloperC/conventional_commits_next_version/-/issues](https://gitlab.com/DeveloperC/conventional_commits_next_version/-/issues).

==> conventional_commits_next_version_lib-0.2.0.crate: conventional_commits_next_version_lib-0.2.0/README.md <==
# Conventional Commits Next Version Library
[![Documentation](https://docs.rs/conventional_commits_next_version_lib/badge.svg)](https://docs.rs/conventional_commits_next_version_lib)
[![crates.io](https://img.shields.io/crates/v/conventional_commits_next_version_lib)](https://crates.io/crates/conventional_commits_next_version_lib)
[![Pipeline Status](https://gitlab.com/DeveloperC/conventional_commits_next_version/badges/master/pipeline.svg)](https://gitlab.com/DeveloperC/conventional_commits_next_version/commits/master)
[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg)](https://conventionalcommits.org)
[![License](https://img.shields.io/badge/License-AGPLv3-blue.svg)](https://www.gnu.org/licenses/agpl-3.0)


A tooling and language agnostic library to calculate the next semantic version based on the Conventional Commits since the prior version. Supports monorepos.


## Content
 * [Usage](#usage)
   + [Usage - Logging](#usage-logging)
 * [Issues/Feature Requests](#issuesfeature-requests)


## Usage


### Usage - Logging
The crate `log` is used to provide logging.
The environment variable `RUST_LOG` can be used to set the logging level.
See [https://crates.io/crates/log](https://crates.io/crates/log) for more detailed documentation.


## Issues/Feature Requests
To report an issue or request a new feature use [https://gitlab.com/DeveloperC/conventional_commits_next_version/-/issues](https://gitlab.com/DeveloperC/conventional_commits_next_version/-/issues).
